@@ -3,18 +3,21 @@ Main interface for license-manager service type definitions.
 
 Usage::
 
-    from mypy_boto3.license_manager.type_defs import CreateLicenseConfigurationResponseTypeDef
+    ```python
+    from mypy_boto3_license_manager.type_defs import AutomatedDiscoveryInformationTypeDef
 
-    data: CreateLicenseConfigurationResponseTypeDef = {...}
+    data: AutomatedDiscoveryInformationTypeDef = {...}
+    ```
 """
-from datetime import datetime
 import sys
+from datetime import datetime
 from typing import List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -22,41 +25,35 @@ else:
 
 
 __all__ = (
-    "CreateLicenseConfigurationResponseTypeDef",
-    "FilterTypeDef",
     "AutomatedDiscoveryInformationTypeDef",
     "ConsumedLicenseSummaryTypeDef",
+    "LicenseConfigurationAssociationTypeDef",
+    "LicenseConfigurationTypeDef",
+    "LicenseConfigurationUsageTypeDef",
+    "LicenseOperationFailureTypeDef",
+    "LicenseSpecificationTypeDef",
     "ManagedResourceSummaryTypeDef",
+    "MetadataTypeDef",
+    "OrganizationConfigurationTypeDef",
     "ProductInformationFilterTypeDef",
     "ProductInformationTypeDef",
+    "ResourceInventoryTypeDef",
     "TagTypeDef",
+    "CreateLicenseConfigurationResponseTypeDef",
+    "FilterTypeDef",
     "GetLicenseConfigurationResponseTypeDef",
-    "OrganizationConfigurationTypeDef",
     "GetServiceSettingsResponseTypeDef",
     "InventoryFilterTypeDef",
-    "LicenseSpecificationTypeDef",
-    "LicenseConfigurationAssociationTypeDef",
     "ListAssociationsForLicenseConfigurationResponseTypeDef",
-    "MetadataTypeDef",
-    "LicenseOperationFailureTypeDef",
     "ListFailuresForLicenseConfigurationOperationsResponseTypeDef",
-    "LicenseConfigurationTypeDef",
     "ListLicenseConfigurationsResponseTypeDef",
     "ListLicenseSpecificationsForResourceResponseTypeDef",
-    "ResourceInventoryTypeDef",
     "ListResourceInventoryResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
-    "LicenseConfigurationUsageTypeDef",
     "ListUsageForLicenseConfigurationResponseTypeDef",
     "PaginatorConfigTypeDef",
 )
 
-CreateLicenseConfigurationResponseTypeDef = TypedDict(
-    "CreateLicenseConfigurationResponseTypeDef", {"LicenseConfigurationArn": str}, total=False
-)
-
-FilterTypeDef = TypedDict("FilterTypeDef", {"Name": str, "Values": List[str]}, total=False)
-
 AutomatedDiscoveryInformationTypeDef = TypedDict(
     "AutomatedDiscoveryInformationTypeDef", {"LastRunTime": datetime}, total=False
 )
@@ -72,6 +69,77 @@ ConsumedLicenseSummaryTypeDef = TypedDict(
     total=False,
 )
 
+LicenseConfigurationAssociationTypeDef = TypedDict(
+    "LicenseConfigurationAssociationTypeDef",
+    {
+        "ResourceArn": str,
+        "ResourceType": Literal[
+            "EC2_INSTANCE", "EC2_HOST", "EC2_AMI", "RDS", "SYSTEMS_MANAGER_MANAGED_INSTANCE"
+        ],
+        "ResourceOwnerId": str,
+        "AssociationTime": datetime,
+    },
+    total=False,
+)
+
+LicenseConfigurationTypeDef = TypedDict(
+    "LicenseConfigurationTypeDef",
+    {
+        "LicenseConfigurationId": str,
+        "LicenseConfigurationArn": str,
+        "Name": str,
+        "Description": str,
+        "LicenseCountingType": Literal["vCPU", "Instance", "Core", "Socket"],
+        "LicenseRules": List[str],
+        "LicenseCount": int,
+        "LicenseCountHardLimit": bool,
+        "ConsumedLicenses": int,
+        "Status": str,
+        "OwnerAccountId": str,
+        "ConsumedLicenseSummaryList": List["ConsumedLicenseSummaryTypeDef"],
+        "ManagedResourceSummaryList": List["ManagedResourceSummaryTypeDef"],
+        "ProductInformationList": List["ProductInformationTypeDef"],
+        "AutomatedDiscoveryInformation": "AutomatedDiscoveryInformationTypeDef",
+    },
+    total=False,
+)
+
+LicenseConfigurationUsageTypeDef = TypedDict(
+    "LicenseConfigurationUsageTypeDef",
+    {
+        "ResourceArn": str,
+        "ResourceType": Literal[
+            "EC2_INSTANCE", "EC2_HOST", "EC2_AMI", "RDS", "SYSTEMS_MANAGER_MANAGED_INSTANCE"
+        ],
+        "ResourceStatus": str,
+        "ResourceOwnerId": str,
+        "AssociationTime": datetime,
+        "ConsumedLicenses": int,
+    },
+    total=False,
+)
+
+LicenseOperationFailureTypeDef = TypedDict(
+    "LicenseOperationFailureTypeDef",
+    {
+        "ResourceArn": str,
+        "ResourceType": Literal[
+            "EC2_INSTANCE", "EC2_HOST", "EC2_AMI", "RDS", "SYSTEMS_MANAGER_MANAGED_INSTANCE"
+        ],
+        "ErrorMessage": str,
+        "FailureTime": datetime,
+        "OperationName": str,
+        "ResourceOwnerId": str,
+        "OperationRequestedBy": str,
+        "MetadataList": List["MetadataTypeDef"],
+    },
+    total=False,
+)
+
+LicenseSpecificationTypeDef = TypedDict(
+    "LicenseSpecificationTypeDef", {"LicenseConfigurationArn": str}
+)
+
 ManagedResourceSummaryTypeDef = TypedDict(
     "ManagedResourceSummaryTypeDef",
     {
@@ -83,6 +151,12 @@ ManagedResourceSummaryTypeDef = TypedDict(
     total=False,
 )
 
+MetadataTypeDef = TypedDict("MetadataTypeDef", {"Name": str, "Value": str}, total=False)
+
+OrganizationConfigurationTypeDef = TypedDict(
+    "OrganizationConfigurationTypeDef", {"EnableIntegration": bool}
+)
+
 ProductInformationFilterTypeDef = TypedDict(
     "ProductInformationFilterTypeDef",
     {
@@ -94,11 +168,32 @@ ProductInformationFilterTypeDef = TypedDict(
 
 ProductInformationTypeDef = TypedDict(
     "ProductInformationTypeDef",
-    {"ResourceType": str, "ProductInformationFilterList": List[ProductInformationFilterTypeDef]},
+    {"ResourceType": str, "ProductInformationFilterList": List["ProductInformationFilterTypeDef"]},
+)
+
+ResourceInventoryTypeDef = TypedDict(
+    "ResourceInventoryTypeDef",
+    {
+        "ResourceId": str,
+        "ResourceType": Literal[
+            "EC2_INSTANCE", "EC2_HOST", "EC2_AMI", "RDS", "SYSTEMS_MANAGER_MANAGED_INSTANCE"
+        ],
+        "ResourceArn": str,
+        "Platform": str,
+        "PlatformVersion": str,
+        "ResourceOwningAccountId": str,
+    },
+    total=False,
 )
 
 TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str}, total=False)
 
+CreateLicenseConfigurationResponseTypeDef = TypedDict(
+    "CreateLicenseConfigurationResponseTypeDef", {"LicenseConfigurationArn": str}, total=False
+)
+
+FilterTypeDef = TypedDict("FilterTypeDef", {"Name": str, "Values": List[str]}, total=False)
+
 GetLicenseConfigurationResponseTypeDef = TypedDict(
     "GetLicenseConfigurationResponseTypeDef",
     {
@@ -113,25 +208,21 @@ GetLicenseConfigurationResponseTypeDef = TypedDict(
         "ConsumedLicenses": int,
         "Status": str,
         "OwnerAccountId": str,
-        "ConsumedLicenseSummaryList": List[ConsumedLicenseSummaryTypeDef],
-        "ManagedResourceSummaryList": List[ManagedResourceSummaryTypeDef],
-        "Tags": List[TagTypeDef],
-        "ProductInformationList": List[ProductInformationTypeDef],
-        "AutomatedDiscoveryInformation": AutomatedDiscoveryInformationTypeDef,
+        "ConsumedLicenseSummaryList": List["ConsumedLicenseSummaryTypeDef"],
+        "ManagedResourceSummaryList": List["ManagedResourceSummaryTypeDef"],
+        "Tags": List["TagTypeDef"],
+        "ProductInformationList": List["ProductInformationTypeDef"],
+        "AutomatedDiscoveryInformation": "AutomatedDiscoveryInformationTypeDef",
     },
     total=False,
 )
 
-OrganizationConfigurationTypeDef = TypedDict(
-    "OrganizationConfigurationTypeDef", {"EnableIntegration": bool}
-)
-
 GetServiceSettingsResponseTypeDef = TypedDict(
     "GetServiceSettingsResponseTypeDef",
     {
         "S3BucketArn": str,
         "SnsTopicArn": str,
-        "OrganizationConfiguration": OrganizationConfigurationTypeDef,
+        "OrganizationConfiguration": "OrganizationConfigurationTypeDef",
         "EnableCrossAccountsDiscovery": bool,
         "LicenseManagerResourceShareArn": str,
     },
@@ -151,134 +242,46 @@ class InventoryFilterTypeDef(_RequiredInventoryFilterTypeDef, _OptionalInventory
     pass
 
 
-LicenseSpecificationTypeDef = TypedDict(
-    "LicenseSpecificationTypeDef", {"LicenseConfigurationArn": str}
-)
-
-LicenseConfigurationAssociationTypeDef = TypedDict(
-    "LicenseConfigurationAssociationTypeDef",
-    {
-        "ResourceArn": str,
-        "ResourceType": Literal[
-            "EC2_INSTANCE", "EC2_HOST", "EC2_AMI", "RDS", "SYSTEMS_MANAGER_MANAGED_INSTANCE"
-        ],
-        "ResourceOwnerId": str,
-        "AssociationTime": datetime,
-    },
-    total=False,
-)
-
 ListAssociationsForLicenseConfigurationResponseTypeDef = TypedDict(
     "ListAssociationsForLicenseConfigurationResponseTypeDef",
     {
-        "LicenseConfigurationAssociations": List[LicenseConfigurationAssociationTypeDef],
+        "LicenseConfigurationAssociations": List["LicenseConfigurationAssociationTypeDef"],
         "NextToken": str,
     },
     total=False,
 )
 
-MetadataTypeDef = TypedDict("MetadataTypeDef", {"Name": str, "Value": str}, total=False)
-
-LicenseOperationFailureTypeDef = TypedDict(
-    "LicenseOperationFailureTypeDef",
-    {
-        "ResourceArn": str,
-        "ResourceType": Literal[
-            "EC2_INSTANCE", "EC2_HOST", "EC2_AMI", "RDS", "SYSTEMS_MANAGER_MANAGED_INSTANCE"
-        ],
-        "ErrorMessage": str,
-        "FailureTime": datetime,
-        "OperationName": str,
-        "ResourceOwnerId": str,
-        "OperationRequestedBy": str,
-        "MetadataList": List[MetadataTypeDef],
-    },
-    total=False,
-)
-
 ListFailuresForLicenseConfigurationOperationsResponseTypeDef = TypedDict(
     "ListFailuresForLicenseConfigurationOperationsResponseTypeDef",
-    {"LicenseOperationFailureList": List[LicenseOperationFailureTypeDef], "NextToken": str},
-    total=False,
-)
-
-LicenseConfigurationTypeDef = TypedDict(
-    "LicenseConfigurationTypeDef",
-    {
-        "LicenseConfigurationId": str,
-        "LicenseConfigurationArn": str,
-        "Name": str,
-        "Description": str,
-        "LicenseCountingType": Literal["vCPU", "Instance", "Core", "Socket"],
-        "LicenseRules": List[str],
-        "LicenseCount": int,
-        "LicenseCountHardLimit": bool,
-        "ConsumedLicenses": int,
-        "Status": str,
-        "OwnerAccountId": str,
-        "ConsumedLicenseSummaryList": List[ConsumedLicenseSummaryTypeDef],
-        "ManagedResourceSummaryList": List[ManagedResourceSummaryTypeDef],
-        "ProductInformationList": List[ProductInformationTypeDef],
-        "AutomatedDiscoveryInformation": AutomatedDiscoveryInformationTypeDef,
-    },
+    {"LicenseOperationFailureList": List["LicenseOperationFailureTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListLicenseConfigurationsResponseTypeDef = TypedDict(
     "ListLicenseConfigurationsResponseTypeDef",
-    {"LicenseConfigurations": List[LicenseConfigurationTypeDef], "NextToken": str},
+    {"LicenseConfigurations": List["LicenseConfigurationTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListLicenseSpecificationsForResourceResponseTypeDef = TypedDict(
     "ListLicenseSpecificationsForResourceResponseTypeDef",
-    {"LicenseSpecifications": List[LicenseSpecificationTypeDef], "NextToken": str},
-    total=False,
-)
-
-ResourceInventoryTypeDef = TypedDict(
-    "ResourceInventoryTypeDef",
-    {
-        "ResourceId": str,
-        "ResourceType": Literal[
-            "EC2_INSTANCE", "EC2_HOST", "EC2_AMI", "RDS", "SYSTEMS_MANAGER_MANAGED_INSTANCE"
-        ],
-        "ResourceArn": str,
-        "Platform": str,
-        "PlatformVersion": str,
-        "ResourceOwningAccountId": str,
-    },
+    {"LicenseSpecifications": List["LicenseSpecificationTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListResourceInventoryResponseTypeDef = TypedDict(
     "ListResourceInventoryResponseTypeDef",
-    {"ResourceInventoryList": List[ResourceInventoryTypeDef], "NextToken": str},
+    {"ResourceInventoryList": List["ResourceInventoryTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef", {"Tags": List[TagTypeDef]}, total=False
-)
-
-LicenseConfigurationUsageTypeDef = TypedDict(
-    "LicenseConfigurationUsageTypeDef",
-    {
-        "ResourceArn": str,
-        "ResourceType": Literal[
-            "EC2_INSTANCE", "EC2_HOST", "EC2_AMI", "RDS", "SYSTEMS_MANAGER_MANAGED_INSTANCE"
-        ],
-        "ResourceStatus": str,
-        "ResourceOwnerId": str,
-        "AssociationTime": datetime,
-        "ConsumedLicenses": int,
-    },
-    total=False,
+    "ListTagsForResourceResponseTypeDef", {"Tags": List["TagTypeDef"]}, total=False
 )
 
 ListUsageForLicenseConfigurationResponseTypeDef = TypedDict(
     "ListUsageForLicenseConfigurationResponseTypeDef",
-    {"LicenseConfigurationUsageList": List[LicenseConfigurationUsageTypeDef], "NextToken": str},
+    {"LicenseConfigurationUsageList": List["LicenseConfigurationUsageTypeDef"], "NextToken": str},
     total=False,
 )
 
